neEffdecompDS.RdThis function is similar to R function neEffdecomp from the
medflex package.
neEffdecompDS(model.name)the name of a fitted natural effect model object. This is the
object saved on the server-side by the ds.neModel function.
a summary table of the object of class c("neLht", "glht") (see glht). The object additionally inherits from class "neEffdecomp".
The function ds.neEffdecomp automatically extracts relevant causal
parameter estimates from a natural effect model.