neLhtDS.RdThis function is similar to R function neLht from the
medflex package.
neLhtDS(model.name, linfct)a fitted natural effect model object. This is the object saved
on the server-side by the ds.neModel function.
a specification of the linear hypothesis to be tested.
a summary table of the object of class c("neLht", "glht") (see glht).
The function neLhtDS allows to calculate linear combinations of
natural effect model parameter estimates.