neWeightDS.RdThis function is similar to R function neWeight from the
mmedflex package.
neWeightDS(object)a string character, the name of an object used to select a method.
a data frame of class c("data.frame", "expData", "weightData") is assigned at the server-side of each study.
The function 'neWeight' both expands the data along hypothetical exposure values and calculates ratio-of-mediator probability weights.